✨ A simple library for creating beautiful interactive prompts.

Installation
============

.. code-block:: bash
   
      pip install survey

Features
--------

- **Pythonic**: Friendly interface built around simple functions.
- **Lightweight**: No external depencencies for any operating system.
- **Adaptable**: Works with any string formatting and window size.
- **Extensive**: Packed with tweaks and features for any situation.
- **Complete**: Supports Windows 10 (Anniversary Update and up).

Showcase
--------

.. figure:: _static/images/showcase-1.gif
      :alt: Cybersecurity Rotuine

      Cybersecurity Inspector Prompting Routine

.. figure:: _static/images/showcase-2.gif
      :alt: TribalWars Map

      Map Traversal of en130.tribalswars.net

.. toctree::
    :maxdepth: 2

    reference